==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-hadoop2-compat/src/test/java/org/apache/hadoop/hbase/master/TestMetricsMasterProcSourceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.master;

import org.apache.hadoop.hbase.CompatibilitySingletonFactory;
import org.apache.hadoop.hbase.testclassification.MetricsTests;
import org.apache.hadoop.hbase.testclassification.SmallTests;
import org.junit.Test;
import org.junit.experimental.categories.Category;

import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

/**
 *  Test for MetricsMasterProcSourceImpl
 */
@Category({MetricsTests.class, SmallTests.class})
public class TestMetricsMasterProcSourceImpl {

  @Test
  public void testGetInstance() throws Exception {
    MetricsMasterProcSourceFactory metricsMasterProcSourceFactory = CompatibilitySingletonFactory
        .getInstance(MetricsMasterProcSourceFactory.class);
    MetricsMasterProcSource masterProcSource = metricsMasterProcSourceFactory.create(null);
    assertTrue(masterProcSource instanceof MetricsMasterProcSourceImpl);
    assertSame(metricsMasterProcSourceFactory,
            CompatibilitySingletonFactory.getInstance(MetricsMasterProcSourceFactory.class));
  }

}

==> hbase-2.4.9-src.tar.gz: hbase-2.4.9/hbase-hadoop2-compat/src/test/java/org/apache/hadoop/hbase/master/TestMetricsMasterProcSourceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.master;

import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import org.apache.hadoop.hbase.CompatibilitySingletonFactory;
import org.apache.hadoop.hbase.HBaseClassTestRule;
import org.apache.hadoop.hbase.testclassification.MetricsTests;
import org.apache.hadoop.hbase.testclassification.SmallTests;
import org.junit.ClassRule;
import org.junit.Test;
import org.junit.experimental.categories.Category;

/**
 *  Test for MetricsMasterProcSourceImpl
 */
@Category({MetricsTests.class, SmallTests.class})
public class TestMetricsMasterProcSourceImpl {

  @ClassRule
  public static final HBaseClassTestRule CLASS_RULE =
      HBaseClassTestRule.forClass(TestMetricsMasterProcSourceImpl.class);

  @Test
  public void testGetInstance() throws Exception {
    MetricsMasterProcSourceFactory metricsMasterProcSourceFactory = CompatibilitySingletonFactory
        .getInstance(MetricsMasterProcSourceFactory.class);
    MetricsMasterProcSource masterProcSource = metricsMasterProcSourceFactory.create(null);
    assertTrue(masterProcSource instanceof MetricsMasterProcSourceImpl);
    assertSame(metricsMasterProcSourceFactory,
            CompatibilitySingletonFactory.getInstance(MetricsMasterProcSourceFactory.class));
  }

}
